@@ -100,6 +100,9 @@ void payload_type_set_send_fmtp(PayloadType *pt, const char *fmtp);
 void payload_type_append_recv_fmtp(PayloadType *pt, const char *fmtp);
 void payload_type_append_send_fmtp(PayloadType *pt, const char *fmtp);
 
+#define payload_type_get_bitrate(pt)	((pt)->normal_bitrate)
+#define payload_type_get_rate(pt)		((pt)->clock_rate)
+#define payload_type_get_mime(pt)		((pt)->mime_type)
 
 bool_t fmtp_get_value(const char *fmtp, const char *param_name, char *result, size_t result_len);
 
@@ -183,6 +186,7 @@ VAR_DECLSPEC PayloadType payload_type_amr;
 VAR_DECLSPEC PayloadType payload_type_amrwb;
 VAR_DECLSPEC PayloadType payload_type_truespeech;
 VAR_DECLSPEC PayloadType payload_type_evrc0;
+VAR_DECLSPEC PayloadType payload_type_evrcb0;
 
 /* video */
 VAR_DECLSPEC PayloadType payload_type_mpv;
@@ -194,6 +198,8 @@ VAR_DECLSPEC PayloadType payload_type_mp4v;
 VAR_DECLSPEC PayloadType payload_type_theora;
 VAR_DECLSPEC PayloadType payload_type_h264;
 VAR_DECLSPEC PayloadType payload_type_x_snow;
+VAR_DECLSPEC PayloadType payload_type_jpeg;
+
 VAR_DECLSPEC PayloadType payload_type_t140;
 
 /* non standard file transfer over UDP */
